# arqLogger

This library is intended to be used by developers seeking to send logs generated by the strategy outside Arquants infrastructure to be analyze and process.


Author/Maintainer
-----------------

* [Franco Zanuso](https://github.com/fzanuso>)
